@@ -40,9 +40,9 @@ import operator
 import itertools
 import collections
 
-__version__ = '4.4.1'
+__version__ = '4.4.2'
 
-if sys.version >= '3':
+if sys.version_info >= (3,):
     from inspect import getfullargspec
 
     def get_init(cls):
@@ -179,8 +179,7 @@ class FunctionMaker(object):
         # Ensure each generated function has a unique filename for profilers
         # (such as cProfile) that depend on the tuple of (<filename>,
         # <definition line>, <function name>) being unique.
-        filename = '<%s:decorator-gen-%d>' % (
-            __file__, next(self._compile_count))
+        filename = '<decorator-gen-%d>' % next(self._compile_count)
         try:
             code = compile(src, filename, 'single')
             exec(code, evaldict)
